@@ -1,6 +1,6 @@
 context("cluster")
 
-x <- connect()
+x <- connect(warn = FALSE)
 load_shakespeare(x)
 
 test_that("cluster_settings", {
